#include <iostream>
#include <sstream>
#include <fstream>
#include <cerrno>

using namespace std;

#include "t1.h"
#include "t2.h"

string get_file_contents(const char *filename)
{
  ifstream in(filename, ios::in | ios::binary);
  if (in)
  {
    string contents;
    in.seekg(0, ios::end);
    contents.resize(in.tellg());
    in.seekg(0, ios::beg);
    in.read(&contents[0], contents.size());
    in.close();
    return(contents);
  }
  throw(errno);
}

int main(int argc, char *argv[])
{
    if (argc != 2) {
        cerr << "usage: " << argv[0] << " <xml file>" << endl;
        return 1;
    }
    string xml;
    try {
        xml = get_file_contents(argv[1]);
    }
    catch (int e) {
        cerr << "Cannot read '" << argv[1] << "' : got error code " << e << " (" << strerror(e) << ")" << endl;
        return 1;
    }

    try {
        istringstream iss(xml);
        xml_schema::properties props;
        props.schema_location("http://datex2.eu/schema/2_0RC2/2_0", "t1.xsd");
        auto_ptr<t1::D2LogicalModel> p (t1::d2LogicalModel(iss, 0, props));
        cout << "Parsed using t1" << endl;
        return 0;
    }
    catch (const xml_schema::exception& e) {
        cerr << "parsing with t1 gave " << e << endl;
    }
    catch (...) {
        cerr << "parsing with t1 gave unknown exception" << endl;
    }
    try {
        istringstream iss(xml);
        xml_schema::properties props;
        props.schema_location("http://datex2.eu/schema/2_0RC2/2_0", "t2.xsd");
        auto_ptr<t2::D2LogicalModel> p (t2::d2LogicalModel(iss, 0, props));
        cout << "Parsed using t2" << endl;
    }
    catch (const xml_schema::exception& e) {
        cerr << "parsing with t2 gave " << e << endl;
    }
    catch (...) {
        cerr << "parsing with t2 gave unknown exception" << endl;
    }
}
